LodesDataset

Enum LodesDataset 

pub enum LodesDataset {
    OD {
        edition: LodesEdition,
        job_type: LodesJobType,
        od_part: OdPart,
        year: u64,
    },
    RAC {
        edition: LodesEdition,
        job_type: LodesJobType,
        segment: WorkplaceSegment,
        year: u64,
    },
    WAC {
        edition: LodesEdition,
        job_type: LodesJobType,
        segment: WorkplaceSegment,
        year: u64,
    },
}

Variants



OD

Fields

job_type: LodesJobType
od_part: OdPart
year: u64


RAC

Fields

job_type: LodesJobType
year: u64


WAC

Fields

job_type: LodesJobType
year: u64

Implementations

Source

impl LodesDataset

pub fn description(&self) -> String

pub fn dataset_directory(&self) -> String

pub fn create_uri(&self, geoid: &Geoid) -> Result<String, String>

creates a URI to a LODES datasets based on the directory and file naming conventions described in the LODESTechDoc8.1.pdf file. see https://lehd.ces.census.gov/data/lodes/LODES8/LODESTechDoc8.1.pdf

pub fn output_filename(&self, wildcard: &Option<GeoidType>) -> String

pub fn tiger_year(&self) -> u64

LODES editions correspond to specific TIGER/Lines datasets. see LodesEdition::tiger_year for details. this year value should be used when downloading complimentary TIGER/Lines datasets.